DEBUG=True

# MANDATORY DATA URL
# weather info - keys must be in upper case!!!!
QUERY_URL='http://www.wunderground.com/weather-forecast/zmw:10308.1.99999'
#QUERY_URL='http://www.wunderground.com/personal-weather-station/dashboard?ID=KNYSTATE9'

API_URL='http://api.wunderground.com/api/'
API_KEY='663ad86d0906f344'
API_FORECAST='/forecast10day/q/' 
API_CONDITIONS='/conditions/q/' 
PWS='KNYSTATE9'
FORMAT='json'

# these are optional simply to adjust the display of city, state and zip
ZIPCODE=10308
CITY='Staten Island'
STATE='NY'
COUNTRY='USA'


